# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativefirewallOffTopicRuleConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'in_domain_intents': 'list[str]',
        'restricted_intents': 'list[str]',
        'in_domain_intents_sensitivity': 'GenerativefirewallRuleSensitivity',
        'restricted_intents_sensitivity': 'GenerativefirewallRuleSensitivity',
        'experimental_fields': 'dict(str, object)'
    }

    attribute_map = {
        'in_domain_intents': 'inDomainIntents',
        'restricted_intents': 'restrictedIntents',
        'in_domain_intents_sensitivity': 'inDomainIntentsSensitivity',
        'restricted_intents_sensitivity': 'restrictedIntentsSensitivity',
        'experimental_fields': 'experimentalFields'
    }

    def __init__(self, in_domain_intents=None, restricted_intents=None, in_domain_intents_sensitivity=None, restricted_intents_sensitivity=None, experimental_fields=None):  # noqa: E501
        """GenerativefirewallOffTopicRuleConfig - a model defined in Swagger"""  # noqa: E501
        self._in_domain_intents = None
        self._restricted_intents = None
        self._in_domain_intents_sensitivity = None
        self._restricted_intents_sensitivity = None
        self._experimental_fields = None
        self.discriminator = None
        if in_domain_intents is not None:
            self.in_domain_intents = in_domain_intents
        if restricted_intents is not None:
            self.restricted_intents = restricted_intents
        if in_domain_intents_sensitivity is not None:
            self.in_domain_intents_sensitivity = in_domain_intents_sensitivity
        if restricted_intents_sensitivity is not None:
            self.restricted_intents_sensitivity = restricted_intents_sensitivity
        if experimental_fields is not None:
            self.experimental_fields = experimental_fields

    @property
    def in_domain_intents(self):
        """Gets the in_domain_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501

        In_domain_intents is a list of strings that are considered on-topic. Total number of data points in in_domain_intents and restricted_intents should not exceed 500 and total bytes should not exceed 300KB.  # noqa: E501

        :return: The in_domain_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: list[str]
        """
        return self._in_domain_intents

    @in_domain_intents.setter
    def in_domain_intents(self, in_domain_intents):
        """Sets the in_domain_intents of this GenerativefirewallOffTopicRuleConfig.

        In_domain_intents is a list of strings that are considered on-topic. Total number of data points in in_domain_intents and restricted_intents should not exceed 500 and total bytes should not exceed 300KB.  # noqa: E501

        :param in_domain_intents: The in_domain_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: list[str]
        """

        self._in_domain_intents = in_domain_intents

    @property
    def restricted_intents(self):
        """Gets the restricted_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501


        :return: The restricted_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: list[str]
        """
        return self._restricted_intents

    @restricted_intents.setter
    def restricted_intents(self, restricted_intents):
        """Sets the restricted_intents of this GenerativefirewallOffTopicRuleConfig.


        :param restricted_intents: The restricted_intents of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: list[str]
        """

        self._restricted_intents = restricted_intents

    @property
    def in_domain_intents_sensitivity(self):
        """Gets the in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501


        :return: The in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: GenerativefirewallRuleSensitivity
        """
        return self._in_domain_intents_sensitivity

    @in_domain_intents_sensitivity.setter
    def in_domain_intents_sensitivity(self, in_domain_intents_sensitivity):
        """Sets the in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.


        :param in_domain_intents_sensitivity: The in_domain_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: GenerativefirewallRuleSensitivity
        """

        self._in_domain_intents_sensitivity = in_domain_intents_sensitivity

    @property
    def restricted_intents_sensitivity(self):
        """Gets the restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501


        :return: The restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: GenerativefirewallRuleSensitivity
        """
        return self._restricted_intents_sensitivity

    @restricted_intents_sensitivity.setter
    def restricted_intents_sensitivity(self, restricted_intents_sensitivity):
        """Sets the restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.


        :param restricted_intents_sensitivity: The restricted_intents_sensitivity of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: GenerativefirewallRuleSensitivity
        """

        self._restricted_intents_sensitivity = restricted_intents_sensitivity

    @property
    def experimental_fields(self):
        """Gets the experimental_fields of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501

        experimental_fields are fields that are experimental in off topic.  # noqa: E501

        :return: The experimental_fields of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._experimental_fields

    @experimental_fields.setter
    def experimental_fields(self, experimental_fields):
        """Sets the experimental_fields of this GenerativefirewallOffTopicRuleConfig.

        experimental_fields are fields that are experimental in off topic.  # noqa: E501

        :param experimental_fields: The experimental_fields of this GenerativefirewallOffTopicRuleConfig.  # noqa: E501
        :type: dict(str, object)
        """

        self._experimental_fields = experimental_fields

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativefirewallOffTopicRuleConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativefirewallOffTopicRuleConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
