# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeDetailedUpgradeStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'RimeUpgradeStatus',
        'last_update_time': 'datetime',
        'error_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'last_update_time': 'lastUpdateTime',
        'error_message': 'errorMessage'
    }

    def __init__(self, status=None, last_update_time=None, error_message=None):  # noqa: E501
        """RimeDetailedUpgradeStatus - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._last_update_time = None
        self._error_message = None
        self.discriminator = None
        if status is not None:
            self.status = status
        self.last_update_time = last_update_time
        if error_message is not None:
            self.error_message = error_message

    @property
    def status(self):
        """Gets the status of this RimeDetailedUpgradeStatus.  # noqa: E501


        :return: The status of this RimeDetailedUpgradeStatus.  # noqa: E501
        :rtype: RimeUpgradeStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RimeDetailedUpgradeStatus.


        :param status: The status of this RimeDetailedUpgradeStatus.  # noqa: E501
        :type: RimeUpgradeStatus
        """

        self._status = status

    @property
    def last_update_time(self):
        """Gets the last_update_time of this RimeDetailedUpgradeStatus.  # noqa: E501


        :return: The last_update_time of this RimeDetailedUpgradeStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_time

    @last_update_time.setter
    def last_update_time(self, last_update_time):
        """Sets the last_update_time of this RimeDetailedUpgradeStatus.


        :param last_update_time: The last_update_time of this RimeDetailedUpgradeStatus.  # noqa: E501
        :type: datetime
        """
        if last_update_time is None:
            raise ValueError("Invalid value for `last_update_time`, must not be `None`")  # noqa: E501

        self._last_update_time = last_update_time

    @property
    def error_message(self):
        """Gets the error_message of this RimeDetailedUpgradeStatus.  # noqa: E501

        The error message if the status is failed.  # noqa: E501

        :return: The error_message of this RimeDetailedUpgradeStatus.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this RimeDetailedUpgradeStatus.

        The error message if the status is failed.  # noqa: E501

        :param error_message: The error_message of this RimeDetailedUpgradeStatus.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeDetailedUpgradeStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeDetailedUpgradeStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
